@@ -46,6 +46,34 @@ class ASReviewData():
         Specification for which column corresponds to which standard
         specification. Key is the standard specification, key is which column
         it is actually in.
+
+    Attributes
+    ----------
+    record_ids: numpy.ndarray
+        Return an array representing the data in the Index.
+    texts: numpy.ndarray
+        Returns an array with either headings, bodies, or both.
+    headings: numpy.ndarray
+        Returns an array with dataset headings.
+    title: numpy.ndarray
+        Identical to headings.
+    bodies: numpy.ndarray
+        Returns an array with dataset bodies.
+    abstract: numpy.ndarray
+        Identical to bodies.
+    keywords: numpy.ndarray
+        Returns an array with dataset keywords.
+    authors: numpy.ndarray
+        Returns an array with dataset authors.
+    doi: numpy.ndarray
+        Returns an array with dataset DOI.
+    included: numpy.ndarray
+        Returns an array with document inclusion markers.
+    final_included: numpy.ndarray
+        Pending deprecation! Returns an array with document inclusion markers.
+    labels: numpy.ndarray
+        Identical to included.
+
     """
 
     def __init__(self,
@@ -103,28 +131,6 @@ class ASReviewData():
         return hashlib.sha1(" ".join(texts).encode(
             encoding='UTF-8', errors='ignore')).hexdigest()
 
-    def slice(self, idx, by_index=True):
-        """Create a slice from itself.
-
-        Useful if some parts should be kept/thrown away.
-
-        Arguments
-        ---------
-        idx: list, numpy.ndarray
-            Record ids that should be kept.
-
-        Returns
-        -------
-        ASReviewData
-            Slice of itself.
-        """
-        if self.df is None:
-            raise ValueError("Cannot slice empty ASReviewData object.")
-
-        if by_index:
-            return ASReviewData(self.df.iloc[idx], data_name="sliced")
-        return ASReviewData(self.df.loc[idx, :], data_name="sliced")
-
     def append(self, as_data):
         """Append another ASReviewData object.
 
@@ -322,6 +328,13 @@ class ASReviewData():
         except KeyError:
             return None
 
+    @property
+    def doi(self):
+        try:
+            return self.df[self.column_spec["doi"]].values
+        except KeyError:
+            return None
+
     def get(self, name):
         "Get column with name."
         try:
