@@ -1,17 +1,31 @@
+# Copyright 2019-2021 The ASReview Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from sklearn.feature_extraction.text import TfidfVectorizer
 
 from asreview.models.feature_extraction.base import BaseFeatureExtraction
 
 
 class Tfidf(BaseFeatureExtraction):
-    """Class to apply TF-IDF to texts.
+    """TF-IDF feature extraction technique.
 
-    Use the standard TF-IDF (Term Frequency-Inverse Document Frequency)
-    feature extraction from `SKLearn <https://scikit-learn.org/stable/modules/
-    generated/sklearn.feature_extraction.text.TfidfVectorizer.html>`__. Gives
-    a sparse matrix as output. Works well in combination with
-    :class:`asreview.models.NBModel` and other fast training models (given
-    that the features vectors are relatively wide).
+    Use the standard TF-IDF (Term Frequency-Inverse Document Frequency) feature
+    extraction technique from `SKLearn <https://scikit-learn.org/stable/modules/
+    generated/sklearn.feature_extraction.text.TfidfVectorizer.html>`__. Gives a
+    sparse matrix as output. Works well in combination with
+    :class:`asreview.models.classifiers.NaiveBayesClassifier` and other fast
+    training models (given that the features vectors are relatively wide).
 
     Arguments
     ---------
@@ -23,6 +37,7 @@ class Tfidf(BaseFeatureExtraction):
         do not use stop words.
     """
     name = "tfidf"
+    label = "TF-IDF"
 
     def __init__(self, *args, ngram_max=1, stop_words="english", **kwargs):
         """Initialize tfidf class.
